#===========================================================
%define midasroot    /usr/local
%define midasversion 1.9.2
%define midasrelease 1
#
Name:    midas
Version: %{midasversion}
Release: %{midasrelease}
Source:  http://midas.triumf.ca/download/midas-%{midasversion}.tar.gz
Source1: midas.ps.gz
Source2: midas_intro.jpg
Copyright: GPL
URL: http://midas.psi.ch
Icon: midas.xpm
Summary: Maximum Integrated Data Acquisition System (MIDAS) 
Group: Applications/Physics
BuildRoot: /var/tmp/root-midas-%{midasversion}
#
%description 
The Maximum Integrated Data Acquisition System (MIDAS) is a
general-purpose system for event based data acquisition in small and
medium scale physics experiments. It has been developed at the Paul
Scherrer Institute (Switzerland) and at TRIUMF (Canada) between 1993
and 1997. Midas is based on a modular networking capability and a central
database system. MIDAS consists of a C library and several applications.
They run on many different operating systems such as UNIX like, Windows NT,
VxWorks, VMS and MS-DOS. While the system is already in use in several
laboratories, the development continues with new features and tools.
For the newest status, check the MIDAS home page http://midas.triumf.ca.

# ==========================================================
%prep
%setup

# ==========================================================
%build 
make -s PREFIX=%{midasroot}
cp %{SOURCE1} doc/
cp %{SOURCE2} doc/
# fix permissions
find . -name "*.c" -exec chmod 644 {} \;
find . -name "*.h" -exec chmod 644 {} \;
find . -name "*.f" -exec chmod 644 {} \;
find . -name "*.txt" -exec chmod 644 {} \;
find . -name "*akefile*" -exec chmod 644 {} \;
# chmod 644 CHANGELOG README OVERVIEW

# ==========================================================
%install
rm -rf $RPM_BUILD_ROOT
make  -s install PREFIX=$RPM_BUILD_ROOT/%{midasroot}
# force the execute perms for shared library
chmod 755 $RPM_BUILD_ROOT/%{midasroot}/lib/libmidas.so
# create a sample exptab
mkdir $RPM_BUILD_ROOT/etc
echo "# *** sample exptab for MIDAS ver. %{midasversion} *** "  >  $RPM_BUILD_ROOT/etc/exptab
echo "#exptname  /home/username/online username"                >> $RPM_BUILD_ROOT/etc/exptab
#

# ==========================================================
%clean
rm -rf $RPM_BUILD_ROOT

# ==========================================================
%files
# doc
%attr(644, root, root) %doc README OVERVIEW CHANGELOG Makefile

# necessary files to be part of the binary distribution
# these will appear in the /usr/doc/midas-x.x.x-y 
%attr(755, root, root) %doc examples drivers src include
%attr(755, root, root) %doc doc utils

# config
%config(noreplace) /etc/exptab

# binaries
%attr(4711, root, root)  %{midasroot}/bin/dio
%attr( 755, root, root)  %{midasroot}/bin/lazylogger
%attr( 755, root, root)  %{midasroot}/bin/mcnaf
%attr( 755, root, root)  %{midasroot}/bin/mdump
%attr( 755, root, root)  %{midasroot}/bin/mhist
%attr( 755, root, root)  %{midasroot}/bin/mhttpd
%attr( 755, root, root)  %{midasroot}/bin/mlogger
%attr( 755, root, root)  %{midasroot}/bin/mlxspeaker
%attr( 755, root, root)  %{midasroot}/bin/mserver
%attr( 755, root, root)  %{midasroot}/bin/mstat
%attr( 755, root, root)  %{midasroot}/bin/mchart
%attr( 755, root, root)  %{midasroot}/bin/stripchart.tcl
%attr( 755, root, root)  %{midasroot}/bin/mtape
%attr( 755, root, root)  %{midasroot}/bin/odbedit
%attr( 755, root, root)  %{midasroot}/bin/odbhist
# disappeared from 1.9.1
#%attr( 755, root, root)  %{midasroot}/bin/elog
# libraries
%attr( 644, root, root)  %{midasroot}/lib/libmidas.a  
%attr( 755, root, root)  %{midasroot}/lib/libmidas.so
%attr( 644, root, root)  %{midasroot}/lib/mana.o
%attr( 644, root, root)  %{midasroot}/lib/mfe.o
%attr( 644, root, root)  %{midasroot}/lib/fal.o
# includes
%attr( 644, root, root)  %{midasroot}/include/*

# ==========================================================
%post
if [ "$1" = 1 ];then
    # change /etc/services
    if  ! grep midas /etc/services > /dev/null; then
        cp   /etc/services /etc/services.premidas
        cp   /etc/services /etc/services.tmp
        echo "midas 1175/tcp   # midas daq server"  >> /etc/services.tmp
        mv   /etc/services.tmp /etc/services 
        echo "midas......Install > /etc/services updated"
    fi
    #
    # figure out if we are inetd or xinetd
    if [ -f /etc/inetd.conf ] ; then
        # inetd.conf is installed
        # change /etc/inetd.conf
        if ! grep midas /etc/inetd.conf > /dev/null; then
            cp  /etc/inetd.conf /etc/inetd.conf.premidas
            cp  /etc/inetd.conf /etc/inetd.conf.tmp
            echo "#midas daq server" >> /etc/inetd.conf.tmp
            echo "midas stream tcp nowait root %{midasroot}/bin/mserver %{midasroot}/bin/mserver" >> /etc/inetd.conf.tmp
            mv /etc/inetd.conf.tmp /etc/inetd.conf
            echo "midas......Install > /etc/inetd.conf updated"
            pid=`ps -A | grep inet | awk '{print $1}'`
            kill -HUP $pid
            echo "midas......Install > Daemon inetd restarted"
        fi
    fi
    if [ -d /etc/xinetd.d ]; then
        # xinetd config dir exists in the standard place
        # create entry in /etc/xinetd.d
        if [ -f /etc/xinetd.d/%{name} ]; then /bin/mv -f /etc/xinetd.d/%{name} /etc/xinetd.d/%{name}.rpmsave; fi
        echo "# default: off"                                       >> /etc/xinetd.d/%{name}
        echo "# description: the midas server"                      >> /etc/xinetd.d/%{name}
        echo " "                                                    >> /etc/xinetd.d/%{name}
        echo "service midas"                                        >> /etc/xinetd.d/%{name}
        echo "{"                                                    >> /etc/xinetd.d/%{name}
        echo "         disable = yes"                               >> /etc/xinetd.d/%{name}
        echo "         socket_type     = stream"                    >> /etc/xinetd.d/%{name}
        echo "         wait            = no"                        >> /etc/xinetd.d/%{name}
        echo "         user            = root"                      >> /etc/xinetd.d/%{name}
        echo "         server          = %{midasroot}/bin/mserver"  >> /etc/xinetd.d/%{name}
        echo "         server_args     = --daemon"                  >> /etc/xinetd.d/%{name}
        echo "        log_on_failure  += HOST"                      >> /etc/xinetd.d/%{name}
        echo "}"                                                    >> /etc/xinetd.d/%{name}
        echo "midas......Install > /etc/xinetd.d/midas updated"
    fi

    # change /etc/ld.so.conf
    if ! grep %{midasroot}/lib /etc/ld.so.conf > /dev/null; then
        cp  /etc/ld.so.conf /etc/ld.so.conf.premidas
        cp  /etc/ld.so.conf /etc/ld.so.conf.tmp
        echo "#midas so library location" >> /etc/ld.so.conf.tmp
        echo "%{midasroot}/lib" >> /etc/ld.so.conf.tmp
        mv /etc/ld.so.conf.tmp /etc/ld.so.conf
        /sbin/ldconfig
        echo "midas......Install > /etc/ld.so.conf updated"
    fi
    # Creates logical links
        cd %{midasroot}/bin
        ln -fs  odbedit odb
        echo "midas......Install > odb link done"
        ln -fs  stripchart.tcl stripchart
        echo "midas......Install > stripchart link done"
    ### done 
    echo "midas......Install > remember to edit /etc/exptab to include your experiment"
    echo " "
    echo "Check the midas web page for latest news."
    echo "http://midas.psi.ch or http://midas.triumf.ca"
    echo " "
fi

# Create a copy of the source in a more usable area and allow read access
cp -pr /usr/share/doc/midas-%{midasversion}/ %{midasroot}/midas-%{midasversion}
chmod 755 -R %{midasroot}/midas-%{midasversion}
# fix permissions
cd %{midasroot}
find . -name "*.c" -exec chmod 644 {} \;
find . -name "*.h" -exec chmod 644 {} \;
find . -name "*.f" -exec chmod 644 {} \;
find . -name "*.txt" -exec chmod 644 {} \;
find . -name "*akefile*" -exec chmod 644 {} \;

# Setup symbolic link to midas
rm -f /midas
ln -s %{midasroot}/midas-%{midasversion} /midas

# ==========================================================
%postun
if [ "$1" = 0 ];then
    # change /etc/services
    if grep midas /etc/services > /dev/null ; then
        cp /etc/services /etc/services.tmp
        grep -v midas /etc/services > /etc/services.tmp
        mv /etc/services.tmp /etc/services
        echo "midas......Remove > /etc/services updated"
    fi

    # figure out if we are inetd or xinetd
    if [ -f /etc/inetd.conf ] ; then
        # inetd is installed according to RPM
        # change /etc/inetd.conf
        # change /etc/inetd.conf
        if grep midas /etc/inetd.conf > /dev/null; then
            cp  /etc/inetd.conf /etc/inetd.conf.tmp
            grep -v midas /etc/inetd.conf >  /etc/inetd.conf.tmp
            mv /etc/inetd.conf.tmp /etc/inetd.conf
            pid=`ps -A | grep inet | awk '{print $1}'`
            echo "midas......Remove > /etc/inetd.conf updated"
            kill -HUP $pid
            echo "midas......Remove > Daemon inetd restarted"
        fi
    fi
    # xinetd is installed according to RPM
    # move entry to save name entry in /etc/xinetd.d
    if [ -f /etc/xinetd.d/%{name} ]; then 
        /bin/rm -f /etc/xinetd.d/%{name}
        echo "midas......Remove > /etc/xinetd.d/midas"
    fi

    # remove the links that are now stale
    rm -f %{midasroot}/bin/odb
    rm -f %{midasroot}/bin/stripchart
fi

# Remove midas source copy
rm -rf %{midasroot}/midas-%{midasversion}
# Remoce symbolic link to Midas
rm -f /midas

##### End 
